@@ -28,6 +28,7 @@ from subprocess import (
     PIPE,
     STDOUT,
 )
+import unittest
 
 import pytest
 
@@ -43,6 +44,7 @@ files_to_test.extend(glob.glob(os.path.join(_top_dir, "testing/*.py")))
 files_to_test.remove(os.path.join(_top_dir, "duplicity/argparse311.py"))
 
 
+@unittest.skipIf(os.environ.get("USER", "") == "buildd", "Skip test on Launchpad")
 class CodeTest(DuplicityTestCase):
     def run_checker(self, cmd, returncodes=None):
         if returncodes is None:
@@ -65,6 +67,7 @@ class CodeTest(DuplicityTestCase):
             [
                 "black",
                 "--check",
+                "--required-version=23.7.0",
             ]
             + files_to_test,
         )
